#========================================================================================
# package      DE_EPAGES::Core::API::ImageOptimization
# state        public
#----------------------------------------------------------------------------------------
# description  This module provides an API for image optimizations tools like optipng.
#========================================================================================
package DE_EPAGES::Core::API::ImageOptimization;
use base Exporter;

use strict;
use Config;
use DE_EPAGES::Core::API::File qw ( CorrectPathSlashes );
use DE_EPAGES::Core::API::SystemCommand qw( SystemCommand );

our @EXPORT_OK = qw (
    OptiPng
    MassOptiPng
);

#========================================================================================
# function     OptiPng
# state        public
#----------------------------------------------------------------------------------------
# syntax       my $ReturnCode = OptiPng($ActualFullFileName, $hOptions);
# example      $self->OptiPng("C:\\temp\\test.png");
#----------------------------------------------------------------------------------------
# description  Apply external OptiPng application to optimize the file size of the
#               final png image. Uses executeable version of OptiPng via SystemCommand.
#----------------------------------------------------------------------------------------
# input        $ActualFullFileName | full file path-name of the image to optimize
#               | string
# input        $hOptions | options
#               <ul>
#                   <li>optipngmethod  - (optional) use this optipng method
#               </ul>
#               | ref.hash
#========================================================================================
sub OptiPng {
    my ($FileName, $hOptions) = @_;
    # optimize that copy
    my $OptiPngApp = CorrectPathSlashes($ENV{'EPAGES_PERL'} . '/bin/optipng');
    my @Params = (
        '-quiet',                          # not output
    );
    push(@Params, $hOptions->{'optipngmethod'} ? $hOptions->{'optipngmethod'} : '-o2'); #defaul is 2
    push(@Params, $FileName);
    SystemCommand([$OptiPngApp, @Params], { 'Print' => 0 });

}

#========================================================================================
# function     MassOptiPng
# state        public
#----------------------------------------------------------------------------------------
# syntax       my $ReturnCode = MassOptiPng($aActualFullFileName, $hOptions);
# example      $self->OptiPng(["C:\\temp\\test.png", "C:\\temp\\test2.png"]);
#----------------------------------------------------------------------------------------
# description  Apply external OptiPng application to optimize the file size of the
#               final png images. Uses executeable version of OptiPng via SystemCommand.
#----------------------------------------------------------------------------------------
# input        $aActualFullFileName | full file path-name of the image to optimize
#               | string
# input        $hOptions | options
#               <ul>
#                   <li>optipngmethod  - (optional) use this optipng method
#               </ul>
#               | ref.hash
#========================================================================================
sub MassOptiPng {
    my ($aFileNames, $hOptions) = @_;

    # optimize that copy
    my $OptiPngApp = CorrectPathSlashes($ENV{'EPAGES_PERL'} . '/bin/optipng');
    my @Params = (
        '-quiet',                          # not output
    );
    push(@Params, $hOptions->{'optipngmethod'} ? $hOptions->{'optipngmethod'} : '-o2'); #defaul is 2

    push(@Params, $_) foreach @$aFileNames;
    SystemCommand([$OptiPngApp, @Params], { 'Print' => 0 });

}
1;
