#========================================================================================
# package      DE_EPAGES::Coupon::t::CouponAndCampaignResource
# base         DE_EPAGES::Shop::API::TestImportXML
# state        public
#----------------------------------------------------------------------------------------
# description  Integration test for CouponCampaignCollectionResource and CouponCampaign
#========================================================================================
package DE_EPAGES::Coupon::t::CouponAndCampaignResource;
use base DE_EPAGES::Shop::API::TestImportXML;

use DE_EPAGES::Coupon::API::Resource::CouponCampaignCollectionResource;
use DE_EPAGES::Coupon::API::Resource::CouponCampaignResource;
use DE_EPAGES::Coupon::API::Resource::CouponResource;

use Test::More;
use Test::Exception;
use strict;



sub shopAlias {
    return 'RestApiTestShop';
}

sub importXMLPath {
    return 'ShopXMLs/Shop_for_Campaign_test.xml';
}



sub test {
    my $self = shift;
    my $NewCampaign = $self->test_createAndGetCampaign();
    $self->test_createCouponForCampaign($NewCampaign);
    $self->test_createShippingCampaignAndBadRequest();
    $self->test_createFixCampaign();
    done_testing();
}




sub test_createCouponForCampaign {
    my $self = shift;
    my ($Campaign) = @_;

    my $CampaignResource = DE_EPAGES::Coupon::API::Resource::CouponResource->new();
    my $hPostRequest = {'code'=>'coupon_code_created_by_a_test'};
    my $Response = $CampaignResource->put($Campaign,$hPostRequest);
    is($Response, undef, 'Test if creating coupon for a campain does not throw an error');
    my $CreatedCoupon = $self->shop->folder('CouponCodes')->child('coupon_code_created_by_a_test');
    is($CreatedCoupon->alias(), 'coupon_code_created_by_a_test', 'Test if created coupon exists in shop');
    throws_ok(sub{$CampaignResource->put($Campaign,$hPostRequest)},qr/BadRequest/,'Test error if coupon can not be created with existing alias');
}


sub test_createAndGetCampaign {
    my $self = shift;
    my $Resource = DE_EPAGES::Coupon::API::Resource::CouponCampaignCollectionResource->new();
    my $CampaignResource = DE_EPAGES::Coupon::API::Resource::CouponCampaignResource->new();
    my $Shop = $self->shop();
    my $LocaleID = 'en_GB';
    my $hPostRequest ={
            'identifier' => 'id01',
            'currency' => 'GBP',
            'name' => 'testcname',
            'type'=> {
                    'name' => 'PERCENT',
                    'shippingCostsIncluded'=> '1',
                    'percentage'=> '77'
                    }
        };
    my $CreatedResponse = $Resource->post($Shop, $LocaleID, $hPostRequest);
    my $CreatedCampaign = $self->shop->folder('CouponCampaigns')->child('id01');
    my $ExpectedCampaign = $CampaignResource->get($CreatedCampaign, $LocaleID);

    is_deeply($ExpectedCampaign, $CreatedResponse, 'Test GET and POST CouponCampaign');
    is($CreatedResponse->{'type'}->{'percentage'},'77','Test campaign type as percentage');
    is($CreatedResponse->{'type'}->{'shippingCostsIncluded'},'true','Test campaign with shippingCosts');
    is($CreatedResponse->{'name'},'testcname','Test campaign name');
    is($CreatedResponse->{'identifier'},'id01','Test campaign alias');
    is($CreatedResponse->{'currency'},'GBP','Test campaign currency');

    return $CreatedCampaign;
}

sub test_createFixCampaign {
    my $self = shift;
    my $Resource = DE_EPAGES::Coupon::API::Resource::CouponCampaignCollectionResource->new();
    my $Shop = $self->shop();
    my $LocaleID = 'en_GB';
    my $hPostRequest ={
            'identifier' => 'id02',
            'currency' => 'GBP',
            'name' => 'testcname',
            'type'=> {
                    'name' => 'FIX',
                    'shippingCostsIncluded'=> '0',
                    'waiveShippingCosts'=> '0',
                    'amount'=> '10'
                    }
        };
    my $CreatedResponse = $Resource->post($Shop, $LocaleID, $hPostRequest);
    is($CreatedResponse->{'type'}->{'amount'},'10','Test coupon type as percentage');
    is($CreatedResponse->{'type'}->{'shippingCostsIncluded'},'false','Test coupon without shippingCosts');
}

sub test_createShippingCampaignAndBadRequest {
    my $self = shift;
    my $Resource = DE_EPAGES::Coupon::API::Resource::CouponCampaignCollectionResource->new();
    my $Shop = $self->shop();
    my $LocaleID = 'en_GB';
    my $hPostRequest ={
            'identifier' => 'id03',
            'currency' => 'GBP',
            'name' => 'testcname',
            'type'=> {
                    'name' => 'SHIPPING',
                    'waiveShippingCosts'=> '1'
                    }
        };
    my $CreatedResponse = $Resource->post($Shop, $LocaleID, $hPostRequest);
    is($CreatedResponse->{'type'}->{'waiveShippingCosts'},'true','Test waive shipping costs');
    throws_ok(sub{$Resource->post($Shop, $LocaleID, $hPostRequest)},qr/BadRequest/,'Test error if campaign can not be created if with existing alias');
}


__PACKAGE__->runScript();



1;