#========================================================================================
# package      DE_EPAGES::Ebay::DAL::Categories
# state        private
# description  database interface for ebay categories:
#========================================================================================
package DE_EPAGES::Ebay::DAL::Categories;
use base qw (Exporter);

use strict;
use DE_EPAGES::Core::API::Log qw ( GetLog );
use DE_EPAGES::Database::API::Connection qw (  GetCurrentDBHandle );

our @EXPORT_OK = qw ( DAL_GetRecentCategories );

sub _CallDriver {
    my ($FunctionName, @Parameter) = @_;
    my $dbi = GetCurrentDBHandle();
    my $Package = 'DE_EPAGES::Ebay::DAL::'.$dbi->driverName.'::Categories';
    DE_EPAGES::Core::API::PerlTools::UsePackage($Package);
    GetLog->debug("call $Package->$FunctionName()");
    return $Package->$FunctionName($dbi, @Parameter);
}

#========================================================================================
# function     DAL_GetRecentCategories
#----------------------------------------------------------------------------------------
# syntax       $RecentCategories = DAL_GetRecentCategories($ShopID,$EnvID);
#----------------------------------------------------------------------------------------
# description  Return all used ebay categories for the given environment id
#----------------------------------------------------------------------------------------
# input        $EnvID | Shop ID | integer
# input        $EnvID | Environment ID | integer
# return       $rahRecentCategories | with following keys:
#               <ul>
#                   <li>EbayCategoryID  - ebay category id  - int
#               </ul>| reference to array of hashes
#========================================================================================
sub DAL_GetRecentCategories ($$;$) {
    my ($ShopID, $EnvID, $hParams) = @_;

    return _CallDriver('GetRecentCategories',$ShopID,$EnvID,$hParams);
}

1;

