const 	gulp = require('gulp'),
		lesshint = require('gulp-lesshint'),
		csslint = require('gulp-csslint'),
		jshint = require('gulp-jshint');

const reporter = {
		id: 'epages',
		name: 'epages',

		endFormat: () => {},
		startFormat: () => {},

		formatResults: (results, filename, fullPath) => {
			// for css
			results.messages.forEach((message) => {
				if (message.type === 'error' && blacklist.indexOf(filename.split('Cartridges')[1]) === -1) {
					console.log('Error in file: "' + filename.split('Cartridges')[1] + '" in line: ' + message.line + ':' + message.col + '.\nMessage: ' + message.message);
				}
			});
		},

		report: (results) => {
			// for less
	    	results.forEach((result) => {
	        	if (result.severity === 'error') {
	        		console.log('Error in file: "' + result.fullPath.split('Cartridges')[1] + '" in line: ' + result.line + ':' + result.column + '.\nMessage: ' + result.linter + ': ' + result.message);
	        	}
	    	});
	    },

	    reporter: (result) => {
	    	// for js
	    	if(result && result.length){
		    	errorList = result.reduce((acc, error) => {
		    		if ( error.error && ignoredErrors.indexOf(error.error.code) === -1 ) {
		    			acc.push('Error in Line ' + error.error.line + ':' + error.error.character + '. Reason: ' + error.error.code + ': ' + error.error.reason)
		    		}
		    		return acc;
		    	} , []);

		    	if(errorList && errorList.length){
			    	console.log('------------------------------------------------------------------------\n' + result[0].file + '\n------------------------------------------------------------------------');
			    	console.log(errorList.join('\n'));
			    	console.log('\n');
			    }
		    }
	    }
	},
	ignoredErrors = ['W069', 'W041', 'W004', 'W014', 'W100', 'W083', 'W018', 'W082', 'W085', 'I001'],
	blacklist = ['/DE_EPAGES/Design/Data/Public/lib/de_epages/design/style-ie.css', '/DE_EPAGES/JQuery/Data/Public/lib/de_epages/jquery/style-package-testsuite.css', '/DE_EPAGES/Order/Data/Public/lib/de_epages/order/style-shoppingbasket-sf.css'];

let jsReport = [];

gulp.task('less', () => {
  return gulp.src(['/srv/epages/eproot/Cartridges/DE_EPAGES/**/Data/Public/lib/de_epages/**/*.less', '/srv/epages/eproot/Cartridges/DE_EPAGES/**/Data/Public/lib/ep/**/*.less'])
        .pipe(lesshint({
            // Options
        }))
        .pipe(lesshint.reporter(reporter))
        .pipe(lesshint.failOnError()); // Use this to fail the task on lint errors
});

gulp.task('css', function() {
  return gulp.src(['/srv/epages/eproot/Cartridges/DE_EPAGES/**/Data/Public/lib/de_epages/**/*.css', '/srv/epages/eproot/Cartridges/DE_EPAGES/**/Data/Public/lib/ep/**/*.css'])
    .pipe(csslint())
    .pipe(csslint.formatter(reporter));
});

gulp.task('lint', ['less', 'css'], () => {
	gulp.start(['js']);
});

gulp.task('js', function() {
  return gulp.src(['/srv/epages/eproot/Cartridges/DE_EPAGES/**/Data/Public/lib/de_epages/**/*.js', '/srv/epages/eproot/Cartridges/DE_EPAGES/**/Data/Public/lib/ep/**/*.js'])
    .pipe(jshint())
    .pipe(jshint.reporter(reporter));
});