#==============================================================================
# package      DE_EPAGES::PayPalExpress::UI::Order
# state        private
#==============================================================================
package DE_EPAGES::PayPalExpress::UI::Order;
use base DE_EPAGES::Presentation::UI::Object;

use strict;
use DE_EPAGES::Core::API::Error qw ( Error ExistsError GetError );
use DE_EPAGES::Core::API::Warning qw ( Warning );
use DE_EPAGES::ExternalPayment::API::Log qw ( LogPayment );
use DE_EPAGES::Object::API::Factory qw ( LoadRootObject );
use DE_EPAGES::PayPalExpress::API::Payment qw ( CheckoutRequestDetails DoCheckoutPayment );

use DE_EPAGES::PayPalExpress::API::Constants  qw ( TRANSSTATUS_CANCELED TRANSSTATUS_FAILED );
#==============================================================================
# used for callback after standard payment when payment is on order
sub PayPalExpressReturn {
    my $self     = shift;
    my ($Servlet) = @_;

    my $Order = $Servlet->object();
    return unless defined (my $LineItemContainer = $Order->container());

    my $LineItemPayment = $LineItemContainer->get('Payment');

    # EPG-24383: check if payment is already processed
    my $APIStep = $LineItemPayment->get('Field1');
    return if (defined $APIStep and $APIStep eq 'DoExpressCheckoutPayment');

    my $hResult;
    eval {
        CheckoutRequestDetails($LineItemPayment, {'ObjectID' => $Order->id()});
        $hResult = DoCheckoutPayment($LineItemPayment, {'ObjectID' => $Order->id()});
    };
    if (ExistsError()) {
        my $Error = GetError();

        if ($Error->code() eq 'SEND_MAIL_FAILED') {
            Warning($Error)
        }
        elsif ($Error->code() eq 'PayPalExpressFailed') {
            $LineItemPayment->setTransactionTo(TRANSSTATUS_FAILED, $Error->vars()->{'ErrorCode'});
            Error('INVALID_FORM', {
                'ViewVars' => {
                    'FormError' => 0,
                    'ErrorCode' => 'PayPalExpressInvalid',
                    'CorrelationID' => $Error->vars()->{'CorrelationID'},
                    'PPEErrorCode'  => $Error->vars()->{'ErrorCode'},
                    'PayPalMessage' => $Error->vars()->{'LongMessage'}
                },
                'ViewAction' => 'ViewPayPalExpressFailed'
            });
        }
        else {
            Error($Error);
        }
    }

    #--- giropay redirect if necessary
    if (defined($hResult) and defined($hResult->{'REDIRECTREQUIRED'}) and lc($hResult->{'REDIRECTREQUIRED'}) eq 'true') {
        LogPayment('PayPalExpress', 'REDIRECTREQUIRED is true, call PayPalExpressGiroPayRedirect', {
            'OrderID'   => $Order->id(),
            'OrderPath' => $Order->pathString()
        });
        $Servlet->vars('ViewAction', 'PayPalExpressGiroPayRedirect');
    }

    return;
}

#==============================================================================
sub PayPalExpressGiroPayRedirect {
    my $self     = shift;
    my ($Servlet) = @_;

    my $Order = $Servlet->object;
    my $pli = $Order->container->get('Payment');

    my $url = LoadRootObject()->get($pli->get('IsTestTransaction')  ?  'PayPalExpress_SandboxURL_GiroPay' : 'PayPalExpress_ProductionURL_GiroPay');
    $url .= $pli->get('Token');

    LogPayment('PayPalExpress', "redirecting customer to $url", {'OrderID' => $Order->id, 'OrderPath' => $Order->pathString});
    $Servlet->vars('ExitAfterEvent', 1);
    $Servlet->vars('ResponseContentProcessed', 1);
    my $Response = $Servlet->response;
    $Response->code(302);
    $Response->header('Location', $url);

    return;
}

sub ViewPayPalExpressCancel {
    my $self     = shift;
    my ($Servlet) = @_;

    my $Order = $Servlet->object;
    my $Shop = $Order->get('Shop');

    $self->_setCancelToTransactionStatusOf($Order);

    if ($Shop->get('IsUnityRegistered')) {
        my $LineItemPayment = $Order->container()->get('Payment');
        $LineItemPayment->set({'PaymentErrorCode' => 'Canceled'});
        $Servlet->redirect($Order->get('WebUrlUnitySSL'));
    }
}

sub _setCancelToTransactionStatusOf {
    my $self = shift;
    my ($Order) = @_;

    my $LineItemContainer = $Order->container();
    my $LineItemPayment = $LineItemContainer->get('Payment');
    $LineItemPayment->setTransactionTo(TRANSSTATUS_CANCELED);
    return;
}

1;

