#========================================================================================
# package      DE_EPAGES::PayPalExpress::t::unit::LineItemPaymentPayPalExpress_setTransactionTo
# base         DE_EPAGES::Test::API::UnitTest::Test
#----------------------------------------------------------------------------------------
# description  unit test for method setTransactionTo
#               in package LineItemPaymentPayPalExpress
#========================================================================================
package DE_EPAGES::PayPalExpress::t::unit::LineItemPaymentPayPalExpress_setTransactionTo;
use base DE_EPAGES::Test::API::UnitTest::Test;
use DE_EPAGES::Test::Mock::Mockify;
use Test::More;
use Test::MockObject;
use DE_EPAGES::Test::API::TestTools qw (TestExistsMethod);
use strict;
use DE_EPAGES::Database::API::DBI;

sub test {
    my $self = shift;


    $self->test_setTransactionTo_TransIdEmpty();
    $self->test_setTransactionTo_TransIdAllreadySet();
    $self->test_setTransactionTo_PaypalErrorCodeIsUndef();
    $self->test_setTransactionTo_PaypalErrorCodeIsToLong();

    done_testing();
}
#----------------------------------------------------------------------------------------
sub test_setTransactionTo_TransIdEmpty {
    my $self = shift;
    my $SubTestName = (caller(0))[3];

    my $LineItemPayment = $self->_createSUT({
        'TransID' => undef,
        'PaypalErrorCode' => undef,
    });
    my $PayPalExpressErrorCode = 123456; ## no critic (ProhibitMagicNumbers)
    $LineItemPayment->setTransactionTo('failed', $PayPalExpressErrorCode);

    is($LineItemPayment->get('TransStatus'), 'failed', "$SubTestName - transstatus is set to failed.");
    is($LineItemPayment->get('PaypalErrorCode'), $PayPalExpressErrorCode, "$SubTestName - PaypalErrorCode is set");
    is($LineItemPayment->get('TransID'), '-', "$SubTestName - Undefined transid is set with '-'.");
    is($LineItemPayment->get('TransTime'), 'DateTime', "$SubTestName - DateTime is set.");
}
#----------------------------------------------------------------------------------------
sub test_setTransactionTo_TransIdAllreadySet {
    my $self = shift;
    my $SubTestName = (caller(0))[3];

    my $LineItemPayment = $self->_createSUT({
        'TransID' => 'ec-123456789',
        'PaypalErrorCode' => undef,
    });
    my $PayPalExpressErrorCode = 123456; ## no critic (ProhibitMagicNumbers)
    $LineItemPayment->setTransactionTo('failed', $PayPalExpressErrorCode);

    is($LineItemPayment->get('TransStatus'), 'failed', "$SubTestName - transstatus is set to failed.");
    is($LineItemPayment->get('PaypalErrorCode'), $PayPalExpressErrorCode, "$SubTestName - PaypalErrorCode is set");
    is($LineItemPayment->get('TransID'), 'ec-123456789', "$SubTestName - Keep original value");
    is($LineItemPayment->get('TransTime'), 'DateTime', "$SubTestName - DateTime is set.");
}
#----------------------------------------------------------------------------------------
sub test_setTransactionTo_PaypalErrorCodeIsUndef {
    my $self = shift;
    my $SubTestName = (caller(0))[3];

    my $LineItemPayment = $self->_createSUT({
        'TransID' => undef,
        'PaypalErrorCode' => 'OldError',
    });
    my $PayPalExpressErrorCode = undef;
    $LineItemPayment->setTransactionTo('failed', $PayPalExpressErrorCode);

    is($LineItemPayment->get('TransStatus'), 'failed', "$SubTestName - transstatus is set to failed.");
    is($LineItemPayment->get('PaypalErrorCode'), undef, "$SubTestName - PaypalErrorCode is set to undef");
    is($LineItemPayment->get('TransID'), '-', "$SubTestName - Undefined transid is set with '-'.");
    is($LineItemPayment->get('TransTime'), 'DateTime', "$SubTestName - DateTime is set.");
}
#----------------------------------------------------------------------------------------
sub test_setTransactionTo_PaypalErrorCodeIsToLong {
    my $self = shift;
    my $SubTestName = (caller(0))[3];

    my $LineItemPayment = $self->_createSUT({
        'TransID' => undef,
        'PaypalErrorCode' => 'OldError',
    });
    my $PayPalExpressErrorCode = 123456789123; ## no critic (ProhibitMagicNumbers)
    $LineItemPayment->setTransactionTo('failed', $PayPalExpressErrorCode);

    is($LineItemPayment->get('TransStatus'), 'failed', "$SubTestName - transstatus is set to failed.");
    is($LineItemPayment->get('PaypalErrorCode'), undef, "$SubTestName - PaypalErrorCode is set to undef");
    is($LineItemPayment->get('TransID'), '-', "$SubTestName - Undefined transid is set with '-'.");
    is($LineItemPayment->get('TransTime'), 'DateTime', "$SubTestName - DateTime is set.");
}
#----------------------------------------------------------------------------------------
# helpers
#----------------------------------------------------------------------------------------
sub _createSUT {
    my $self = shift;
    my ($hSetup) = @_;
    my $hAttributes = {
        'TransID' => $hSetup->{'TransID'},
        'PaypalErrorCode' => $hSetup->{'PaypalErrorCode'},
    };
    my $Mockify = DE_EPAGES::Test::Mock::MockifyEpagesObject->new(
        'DE_EPAGES::PayPalExpress::API::Object::LineItemPaymentPayPalExpress',
        $hAttributes
    );
    $Mockify->mock('_GetCurrentDBHandle', $self->_createcDBI());
    return $Mockify->getMockObject();
}
#----------------------------------------------------------------------------------------
sub _createcDBI {
    my $self = shift;

    TestExistsMethod('DE_EPAGES::Database::API::DBI', 'currentDateTime');
    my $MockedDBI = Test::MockObject->new();
    $MockedDBI->mock('currentDateTime', sub {
        return 'DateTime';
    });

    return $MockedDBI;
}
__PACKAGE__->runScript();