#========================================================================================
# package      DE_EPAGES::Product::Hooks::ShopLanguage
# state        public
# description  adds needed data to products on change of the shop language
#========================================================================================
package DE_EPAGES::Product::Hooks::ShopLanguage;

use strict;

#========================================================================================
# function     OnInsertShopLanguage
#----------------------------------------------------------------------------------------
# syntax       OnInsertShopLanguage( $hParams );
#----------------------------------------------------------------------------------------
# description  write the existing name to all products in the new language
#               (Hook OBJ_InsertShopLanguage)
#----------------------------------------------------------------------------------------
# input        $hParams | primary key of tax class, key is
#               <ul>
#                 <li>Object         - ShopLanguage         - object
#                 <li>ShopLanguageID - object id            - int
#               </ul>
#========================================================================================
sub OnInsertShopLanguage {
    my ($hParams) = @_;

    my $ShopLanguage = $hParams->{'Object'};
    my $Shop = $ShopLanguage->getSite();

    if ($Shop->get('IsUnityRegistered')) {
        my $NewLanguageID = $ShopLanguage->get('LanguageID');
        my $DefaultLanguageID = $Shop->get('LanguageID');

        my $aProducts = $Shop->get('Products');

        foreach my $Product (@$aProducts) {
            _useNameForNewLanguage($Product, $DefaultLanguageID, $NewLanguageID);
            if ($Product->countSubProducts > 0) {
                foreach my $SubProduct (@{$Product->subProducts}) {
                    _useNameForNewLanguage($SubProduct, $DefaultLanguageID, $NewLanguageID);
                }
            }
        }
    }

    return;
}

sub _useNameForNewLanguage {
    my ($Product, $DefaultLanguageID, $NewLanguageID) = @_;

    unless (defined $Product->get('Name', $NewLanguageID)) {
        my $Name = $Product->get('Name', $DefaultLanguageID);
        $Product->set({'Name' => $Name}, $NewLanguageID) if defined $Name;
    }
}

1;
