#========================================================================================
# nocomments
# package      DE_EPAGES::SIA::API::Constants
# state        private
#----------------------------------------------------------------------------------------
# description  constants for cartridge
#========================================================================================
package DE_EPAGES::SIA::API::Constants;
use base Exporter;

use Readonly;

use strict;

our @EXPORT_OK = qw (
    INTERNAL_CARTRIDGE_NAME
    WINDOW_NAME
    EVENT_NAME
    PROTOCOL_VERSION
    TRANSACTION_TYPE_SALE
    TRANSACTION_TYPE_REFUND
    TRANSACTION_TYPE_CANCEL
    SALE_EVENT_NAME
    REFUND_EVENT_NAME
    WORK_ORDER_ID_OFFSET
    ERROR_CODE_OFFSET
    EVENT_NAME_LENGTH
    WINDOW_LENGTH
    PROTOCOL_VERSION_LENGTH
    ID_TERMINAL_LENGTH
    CLIENT_ENTITY_ID_LENGTH
    MERCHANT_ID_LENGTH
    MERCHANT_FUC_LENGTH
    USER_ID_LENGTH
    TRANSACTION_TYPE_LENGTH
    OPC_TOKEN_ID_LENGTH
    WEB_REQUEST_ID_LENGTH
    CARD_EXPIRE_DATE_LENGTH
    TRANSACTION_AMOUNT_LENGTH
    TRANSACTION_CURRENCY_LENGTH
    LANGUAGE_LENGTH
    WORK_ORDER_ID_LENGTH
    ERROR_CODE_LENGTH
    REGISTER_CODE
    FILE_DESCRIPTION
    SIA_ROOT_DIRECTORY
    TRANS_STATUS_PENDING
    TRANS_STATUS_ACCEPTED
    TRANS_STATUS_DECLINED
    FILE_NAME_PART1
    FILE_NAME_PART2
    FILE_NAME_PREFIX_RESPONSE
    $aDefaultPaymentNetworks
    USER_GROUP_ALL_PERMISSION
    DECIMAL_PLACES
    DEFAULTREQUESTCODE
    DEFAULTREQUESTSUBCODE
    DEFAULTREQUESTCODE
    DEFAULTREQUESTSUBCODE
    PRIVATECARDFLAG
    DCCFLAG
    TAXFREEFLAG
    KINDOFLOCATION
    REGIONCODE
    RSAVERIFICATION
    RECURRENTADMITTED
    THREEDSECURECONFIGURATION
    RECURRENTMAXIMUM
    TOKENDAYSOFEXPIRATION
    QUARANTINETIME
    CAPTCHACODE
    TIMESTAMPTIME
    DAYSHISTORY
    GETISSUERBANKCOUNTRY
    GETCOUNTRYIPORIGIN
    ROUTINGLEVEL
    CANCELLATIONOPTIONS
    REFUNDOPTIONS
    REFUNDDAYS
    ERROR_CORRECT
    ERROR_CRITICAL
    ERROR_INPUT_DATA
    ADYENACCOUNT
    );

# This name is used to load objects from database (DON'T CHANGE!)
use constant INTERNAL_CARTRIDGE_NAME    => 'SIA';
use constant FILE_NAME_PART1            => 'CNPSIA01';
use constant FILE_NAME_PART2            => 'FTPSORTB';
use constant FILE_NAME_PREFIX_RESPONSE  => 'SIACNP01';

# Paymentmethod constant configs
use constant SALE_EVENT_NAME        => 1200;
use constant REFUND_EVENT_NAME      => 1220;
use constant WINDOW_NAME            => 'Interface';
use constant PROTOCOL_VERSION       => '0001';

use constant TRANSACTION_TYPE_SALE      => 1200;
use constant TRANSACTION_TYPE_REFUND    => 1220;
use constant TRANSACTION_TYPE_CANCEL    => 1420;

# Offsets of fields

use constant WORK_ORDER_ID_OFFSET => 4;
use constant ERROR_CODE_OFFSET    => 1014;

# Length of fields
use constant EVENT_NAME_LENGTH          => 4;
use constant WINDOW_LENGTH              => 9;
use constant PROTOCOL_VERSION_LENGTH    => 4;
use constant ID_TERMINAL_LENGTH         => 11;
use constant CLIENT_ENTITY_ID_LENGTH    => 4;
use constant MERCHANT_ID_LENGTH         => 15;
use constant MERCHANT_FUC_LENGTH        => 15;
use constant USER_ID_LENGTH             => 50;
use constant OPC_TOKEN_ID_LENGTH        => 2;
use constant TRANSACTION_TYPE_LENGTH    => 4;
use constant WEB_REQUEST_ID_LENGTH      => 20;
use constant CARD_EXPIRE_DATE_LENGTH    => 4;
use constant TRANSACTION_CURRENCY_LENGTH=> 3;
use constant LANGUAGE_LENGTH            => 2;
use constant WORK_ORDER_ID_LENGTH       => 11;
use constant ERROR_CODE_LENGTH          => 4;

# Header Fields
use constant REGISTER_CODE              => 10;
use constant FILE_DESCRIPTION           => 'INTERFACE DE MANTENIMIENTO SCNP I+M - SIA';

use constant SIA_ROOT_DIRECTORY         => '/tmp/SIA';

use constant TRANS_STATUS_PENDING       => 'PENDING';
use constant TRANS_STATUS_ACCEPTED      => 'ACCEPTED';
use constant TRANS_STATUS_DECLINED      => 'DECLINED';

use constant USER_GROUP_ALL_PERMISSION  => '0770';
use constant DECIMAL_PLACES             => 2;

# default params for register merchant
use constant DEFAULTREQUESTCODE         => 'IMN';
use constant DEFAULTREQUESTSUBCODE      => '01';
use constant PRIVATECARDFLAG            => '0';
use constant DCCFLAG                    => '0';
use constant TAXFREEFLAG                => '0';
use constant KINDOFLOCATION             => 'DP';
use constant REGIONCODE                 => 'EC';
use constant RSAVERIFICATION            => 'S';
use constant RECURRENTADMITTED          => 'N';
use constant THREEDSECURECONFIGURATION  => '00';
use constant RECURRENTMAXIMUM           => '0010';
use constant TOKENDAYSOFEXPIRATION      => '0000';
use constant QUARANTINETIME             => '0003';
use constant CAPTCHACODE                => 'N';
use constant TIMESTAMPTIME              => '0300';
use constant DAYSHISTORY                => '0180';
use constant GETISSUERBANKCOUNTRY       => 'N';
use constant GETCOUNTRYIPORIGIN         => 'N';
use constant ROUTINGLEVEL               => '1';
use constant CANCELLATIONOPTIONS        => '1';
use constant REFUNDOPTIONS              => '0';
use constant REFUNDDAYS                 => '0000';
use constant ADYENACCOUNT               => 'Telefonica_Tecnocom';

# Error codes
use constant ERROR_CORRECT    => '0000';
use constant ERROR_CRITICAL   => '0002';
use constant ERROR_INPUT_DATA => '0003';

# default payment networks
Readonly our $aDefaultPaymentNetworks => [
    { 'PaymentNetworkName' => 'Redsys',              'PaymentNetworkID' => '050001' },
    { 'PaymentNetworkName' => 'AMEX',                'PaymentNetworkID' => '030001' },
    { 'PaymentNetworkName' => 'Banco del Austro',    'PaymentNetworkID' => '080001' },
    { 'PaymentNetworkName' => 'Datafast',            'PaymentNetworkID' => '100001' },
    { 'PaymentNetworkName' => 'Banco Internacional', 'PaymentNetworkID' => '090001' },
    { 'PaymentNetworkName' => 'Adyen',               'PaymentNetworkID' => '110001' }
];

1;
