#========================================================================================
# package      DE_EPAGES::SIA::t::unit::Signature
# state        public
# description  Test cases for DE_EPAGES::SIA::Request::Signature.
#========================================================================================
package DE_EPAGES::SIA::t::unit::Signature;
use base DE_EPAGES::Core::API::Test;

use DE_EPAGES::SIA::API::SIAConfig;
use DE_EPAGES::SIA::API::Request::Signature;
use DE_EPAGES::SIA::API::Tools qw (GetToolsInstance);
use DE_EPAGES::SIA::t::unit::MockupObjects qw (CreateMockedSIAConfig);
use Test::MockObject::Extends;
use Test::More;

use strict;

sub test {
    my $self = shift;

    $self->test_getSha256HexString_success();
    $self->test_getFirmToken_success();

    done_testing();
}

sub test_getSha256HexString_success {
    my $self = shift;

    my $SIAConfig      = DE_EPAGES::SIA::API::SIAConfig->new( 'IsInTestMode' => 1 );
    my $Signature      = $self->_createSignatureObject($SIAConfig);
    my $Sha256         = $Signature->getSha256HexString();
    my $ExpectedSha256 = '1cd5369337bce4613e9816a883f060b1247fb87b2397fa0e345d03576b23225b';

    is( $Sha256, $ExpectedSha256, 'SHA 256 hex string' );

    return;
}

sub test_getFirmToken_success {
    my $self = shift;

    my ( $MockedSIAConfig, $RSA ) = CreateMockedSIAConfig();
    my $Signature    = $self->_createSignatureObject($MockedSIAConfig);
    my $FirmTokenHex = $Signature->getFirmToken();
    my $FirmToken    = GetToolsInstance()->hexStringToString($FirmTokenHex);

    is( $RSA->decrypt($FirmToken), $Signature->getSha256HexString(), 'firmToken' );

    return;
}

sub _createSignatureObject {
    my $self = shift;
    my ($SIAConfig) = @_;

    my $Signature = DE_EPAGES::SIA::API::Request::Signature->new(
        'SiaConfig'      => $SIAConfig,
        'IDVERSION'       => 'idVersion',
        'IDTERMINAL'      => 'idTerminal',
        'IDENTIDAD'       => 'idEntidad',
        'IDCOMERCIO'      => 'idComercio',
        'IDSERVICIO'      => '',
        'IDUSUARIO'       => 'idUsuario',
        'IDTM'            => 'iDTM',
        'OPCTOKEN'        => 'opcToken',
        'IDPEDIDO'        => 'idPedido',
        'NOMTITULAR'      => 'nomTitular',
        'CODPAIS'         => 1,
        'PAN'             => 'pan',
        'FECCAD'          => 'fecCad',
        'CVC'             => 'cvc',
        'IMPTRANS'        => 1,
        'CODMON'          => 1,
        'TIMETRANS'       => 'timeTrans',
        'IDIOMA'          => 'idioma',
        'IPORIGEN'        => 'ipOrigen',
        'TOKEN'           => 'token',
        'DESTOKEN'        => 'desToken',
        'fechProOri'      => 'fechProOri',
        'numsiaori'       => 1,
        'EMAILUSUARIO'    => 'eMailUsuario',
        'sesionComercio' => 'sesionComercio',
    );

    return $Signature;
}

__PACKAGE__->runScript();
