#========================================================================================
# package      DE_EPAGES::Shop::Hooks::ShopLanguage
# state        public
# description  copies the default shop name when a shop language is added
#========================================================================================
package DE_EPAGES::Shop::Hooks::ShopLanguage;

use strict;

#========================================================================================
# function     OnInsertShopLanguage
#----------------------------------------------------------------------------------------
# syntax       OnInsertShopLanguage( $hParams );
#----------------------------------------------------------------------------------------
# description  copies the default shop name when a shop language is added
#               (Hook OBJ_InsertShopLanguage)
#----------------------------------------------------------------------------------------
# input        $hParams | primary key of tax class, key is
#               <ul>
#                 <li>Object         - ShopLanguage         - object
#                 <li>ShopLanguageID - object id            - int
#               </ul>
#========================================================================================
sub OnInsertShopLanguage {
    my ($hParams) = @_;

    my $ShopLanguage = $hParams->{'Object'};
    my $Shop = $ShopLanguage->getSite();

    if ($Shop->get('IsUnityRegistered')) {
        my $NewLanguageID = $ShopLanguage->get('LanguageID');
        my $DefaultLanguageID = $Shop->get('LanguageID');

        my $ShopName = $Shop->get('Name', $DefaultLanguageID);
        $Shop->set({'Name' => $ShopName}, $NewLanguageID);
    }

    return;
}

1;
