use Test::More tests => 12;
use strict;

use DE_EPAGES::Core::API::Script qw ( RunScript );
use DE_EPAGES::Database::API::Connection qw ( GetTestSite RunOnStore GetCurrentDBHandle );
use DE_EPAGES::Object::API::Factory qw (
    ExistsObjectByPath
    LoadObjectByPath
    LoadRootObject
);
use DateTime::Duration;


my $ROOTPATH = '/Test';

sub Main {
    Init();

    ## no critic qw(ProhibitMagicNumbers)

    my $Shop = LoadObjectByPath($ROOTPATH)->child('TestShop1');
    ok( $Shop->id, 'create shop ' . $Shop->id );
    ok( $Shop->instanceOf('Shop'), 'Shop is instance of class Shop' );

    # do not display Survey
    ok( !$Shop->get('CanShowShopSurvey'), 'Shop.CanShowShopSurvey' );

    # set needed Attributes
    $Shop->set({'InitialShopWizardStartup'=>0});
    $Shop->parent->parent->set({'ShopSurveyIsActive'=>1});
    $Shop->parent->parent->set({'ShopSurveyShopMinAge'=>0});
    $Shop->parent->parent->set({'ShopSurveyShopMaxAge'=>0});

    # display Survey
    ok( $Shop->get('CanShowShopSurvey'), 'Shop.CanShowShopSurvey' );

    # merchant say no to survey
    $Shop->set({'ShopSurveyWaitForMerchant'=>0});

    # do not display Survey
    ok( !$Shop->get('CanShowShopSurvey'), 'Shop.CanShowShopSurvey' );

    # reenable survey
    $Shop->set({'ShopSurveyWaitForMerchant'=>1});

    # display Survey
    ok( $Shop->get('CanShowShopSurvey'), 'Shop.CanShowShopSurvey' );

    $Shop->parent->parent->set({'ShopSurveyShopMinAge'=>10});

    # do not display Survey because of minage
    ok( !$Shop->get('CanShowShopSurvey'), 'Shop.CanShowShopSurvey' );

    # display Survey now because of minage
    $Shop->set({'CreationDate'=> $Shop->get('CreationDate') - DateTime::Duration->new('days' => 10 ) });
    ok( $Shop->get('CanShowShopSurvey'), 'Shop.CanShowShopSurvey' );

    # retest do not display Survey because of minage
    $Shop->parent->parent->set({'ShopSurveyShopMinAge'=>11});
    ok( !$Shop->get('CanShowShopSurvey'), 'Shop.CanShowShopSurvey' );

    #reset to now
    my $DateTime = GetCurrentDBHandle()->currentDateTime;
    $Shop->set({'CreationDate'=> $DateTime });
    $Shop->parent->parent->set({'ShopSurveyShopMinAge'=>0});

    # display Survey now because of < maxage
    $Shop->parent->parent->set({'ShopSurveyShopMaxAge'=>365});
    ok( $Shop->get('CanShowShopSurvey'), 'Shop.CanShowShopSurvey' );

    # shop > maxage
    $Shop->set({'CreationDate'=> $Shop->get('CreationDate') - DateTime::Duration->new('days' => 366 ) });
    ok( !$Shop->get('CanShowShopSurvey'), 'Shop.CanShowShopSurvey' );

    # reset and retest
    $Shop->parent->parent->set({'ShopSurveyShopMaxAge'=>0});
    ok( $Shop->get('CanShowShopSurvey'), 'Shop.CanShowShopSurvey' );

    ## use critic

    Cleanup();
}

sub Cleanup {
    return 1 if $ENV{'SKIP_CLEANUP'};
    LoadRootObject()->set({'ShopSurveyIsActive' => 0});
    LoadObjectByPath($ROOTPATH)->delete if ExistsObjectByPath($ROOTPATH);
    return 1;
}

sub Init {
    return 1 if LoadRootObject()->existsChild('Test') && $ENV{'SKIP_CLEANUP'};
    Cleanup();
    my $Folder = LoadRootObject()->insertChild( 'Object', { Alias => 'Test' });
    $Folder->insertChild( 'Shop', { Alias => 'TestShop1' } );
    return 1;
}

RunScript( Message => 'long', Sub=> sub {
    RunOnStore( Store => GetTestSite(), Sub => \&Main );
});
