#========================================================================================
# package      DE_EPAGES::Object::API::XML::ObjectImportHandler
# state        private
#----------------------------------------------------------------------------------------
# description  This module implements a SAX2 handler to import object type(s)
#               ProviderStore.
#
# example      use DE_EPAGES::ShopConfiguration::API::XML::ProviderImportHandler;
#========================================================================================
package DE_EPAGES::Object::API::XML::ObjectImportHandler;

use strict;
use DE_EPAGES::Object::API::Factory qw( LoadClassByAlias );

#========================================================================================
# ProviderStore
#========================================================================================
sub start_ProviderStore {
    my $self = shift;
    my ($hElement) = @_;

    my $hAttributes = $self->getAttributes( $hElement );
    my $StoreName = $hAttributes->{'Store'};
    die "Missing attribute Store on element ProviderStore" unless defined $StoreName;
    my $aStores = LoadClassByAlias('Store')->getObjects('ByName', [$StoreName]);
    die "Store $StoreName doesn't exist" if 0 == scalar @$aStores;

    my $Store = $aStores->[0];
    my $Provider = $self->topID('Object');

    $Provider->addStore( $Store ) unless $Provider->hasStore( $Store );
    $Provider->set({'DefaultStore' => $Store }) if $hAttributes->{'IsDefault'};
    $Provider->set({'DefaultStoreUnity' => $Store }) if $hAttributes->{'IsDefaultUnity'};
    return;
}

sub end_ProviderStore {
    my $self = shift;
}

1;
